@@ -6,15 +6,17 @@ function(Ps, q = 1, PhyloTree, Normalize = TRUE, Prune = FALSE, CheckArguments =
   
   # Tree must be either a phylog, phylo or a hclust object
   if (inherits(PhyloTree, "phylog")) {
-    # build a phylo object. Go through an hclust because as.phylo.phylog generates errors
+    # build a phylo object. Go through an hclust because as.phylo.phylog sometimes generates errors
     hTree <- stats::hclust(PhyloTree$Wdist^2/2, "average")
     Tree <- ape::as.phylo.hclust(hTree)
-    # edge lengths are divided by 2 during the conversion. See ?as.phylo.hclust
+    # Double edge.lengths to correct as.phylo.hclust
     Tree$edge.length <- 2*Tree$edge.length
   } else {
     if (inherits(PhyloTree, "hclust")) {
       # build a phylo object
       Tree <- ape::as.phylo.hclust(PhyloTree)
+      # Double edge.lengths to correct as.phylo.hclust
+      Tree$edge.length <- 2*Tree$edge.length
     } else {
       if (inherits(PhyloTree, "phylo")) {
         Tree <- PhyloTree
